@@ -125,7 +125,7 @@ new_gjson (void) {
 
 /* Free malloc'd GJSON resources. */
 static void
-free_json (GJSON * json) {
+free_json (GJSON *json) {
   if (!json)
     return;
 
@@ -142,7 +142,7 @@ set_json_nlines (int newline) {
 /* Make sure that we have enough storage to write "len" bytes at the
  * current offset. */
 static void
-set_json_buffer (GJSON * json, int len) {
+set_json_buffer (GJSON *json, int len) {
   char *tmp = NULL;
   /* Maintain a null byte at the end of the buffer */
   size_t need = json->offset + len + 1, newlen = 0;
@@ -175,7 +175,7 @@ set_json_buffer (GJSON * json, int len) {
  *
  * On success, data is outputted. */
 __attribute__((format (printf, 2, 3)))
-  static void pjson (GJSON * json, const char *fmt, ...) {
+  static void pjson (GJSON *json, const char *fmt, ...) {
   int len = 0;
   va_list args;
 
@@ -197,7 +197,7 @@ __attribute__((format (printf, 2, 3)))
  *
  * On success, data is outputted. */
 void
-fpjson (FILE * fp, const char *fmt, ...) {
+fpjson (FILE *fp, const char *fmt, ...) {
   va_list args;
 
   va_start (args, fmt);
@@ -209,7 +209,7 @@ fpjson (FILE * fp, const char *fmt, ...) {
 
 /* Escape all other characters accordingly. */
 static void
-escape_json_other (GJSON * json, const char **s) {
+escape_json_other (GJSON *json, const char **s) {
   /* Since JSON data is bootstrapped into the HTML document of a report,
    * then we perform the following four translations in case weird stuff
    * is put into the document.
@@ -263,7 +263,7 @@ escape_json_other (GJSON * json, const char **s) {
  *
  * On success, escaped JSON data is outputted. */
 static void
-escape_json_output (GJSON * json, const char *s) {
+escape_json_output (GJSON *json, const char *s) {
   while (*s) {
     switch (*s) {
       /* These are required JSON special characters that need to be escaped. */
@@ -301,7 +301,7 @@ escape_json_output (GJSON * json, const char *s) {
 
 /* Write to a buffer a JSON a key/value pair. */
 static void
-pskeysval (GJSON * json, const char *key, const char *val, int sp, int last) {
+pskeysval (GJSON *json, const char *key, const char *val, int sp, int last) {
   if (!last)
     pjson (json, "%.*s\"%s\": \"%s\",%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -310,7 +310,7 @@ pskeysval (GJSON * json, const char *key, const char *val, int sp, int last) {
 
 /* Output a JSON string key, array value pair. */
 void
-fpskeyaval (FILE * fp, const char *key, const char *val, int sp, int last) {
+fpskeyaval (FILE *fp, const char *key, const char *val, int sp, int last) {
   if (!last)
     fpjson (fp, "%.*s\"%s\": %s,%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -319,7 +319,7 @@ fpskeyaval (FILE * fp, const char *key, const char *val, int sp, int last) {
 
 /* Output a JSON a key/value pair. */
 void
-fpskeysval (FILE * fp, const char *key, const char *val, int sp, int last) {
+fpskeysval (FILE *fp, const char *key, const char *val, int sp, int last) {
   if (!last)
     fpjson (fp, "%.*s\"%s\": \"%s\",%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -328,7 +328,7 @@ fpskeysval (FILE * fp, const char *key, const char *val, int sp, int last) {
 
 /* Output a JSON string key, int value pair. */
 void
-fpskeyival (FILE * fp, const char *key, int val, int sp, int last) {
+fpskeyival (FILE *fp, const char *key, int val, int sp, int last) {
   if (!last)
     fpjson (fp, "%.*s\"%s\": %d,%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -337,7 +337,7 @@ fpskeyival (FILE * fp, const char *key, int val, int sp, int last) {
 
 /* Write to a buffer a JSON string key, uint64_t value pair. */
 static void
-pskeyu64val (GJSON * json, const char *key, uint64_t val, int sp, int last) {
+pskeyu64val (GJSON *json, const char *key, uint64_t val, int sp, int last) {
   if (!last)
     pjson (json, "%.*s\"%s\": %" PRIu64 ",%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -346,7 +346,7 @@ pskeyu64val (GJSON * json, const char *key, uint64_t val, int sp, int last) {
 
 /* Write to a buffer a JSON string key, int value pair. */
 static void
-pskeyfval (GJSON * json, const char *key, float val, int sp, int last) {
+pskeyfval (GJSON *json, const char *key, float val, int sp, int last) {
   if (!last)
     pjson (json, "%.*s\"%s\": \"%05.2f\",%.*s", sp, TAB, key, val, nlines, NL);
   else
@@ -355,35 +355,35 @@ pskeyfval (GJSON * json, const char *key, float val, int sp, int last) {
 
 /* Write to a buffer the open block item object. */
 static void
-popen_obj (GJSON * json, int iisp) {
+popen_obj (GJSON *json, int iisp) {
   /* open data metric block */
   pjson (json, "%.*s{%.*s", iisp, TAB, nlines, NL);
 }
 
 /* Output the open block item object. */
 void
-fpopen_obj (FILE * fp, int iisp) {
+fpopen_obj (FILE *fp, int iisp) {
   /* open data metric block */
   fpjson (fp, "%.*s{%.*s", iisp, TAB, nlines, NL);
 }
 
 /* Write to a buffer a JSON open object attribute. */
 static void
-popen_obj_attr (GJSON * json, const char *attr, int sp) {
+popen_obj_attr (GJSON *json, const char *attr, int sp) {
   /* open object attribute */
   pjson (json, "%.*s\"%s\": {%.*s", sp, TAB, attr, nlines, NL);
 }
 
 /* Output a JSON open object attribute. */
 void
-fpopen_obj_attr (FILE * fp, const char *attr, int sp) {
+fpopen_obj_attr (FILE *fp, const char *attr, int sp) {
   /* open object attribute */
   fpjson (fp, "%.*s\"%s\": {%.*s", sp, TAB, attr, nlines, NL);
 }
 
 /* Close JSON object. */
 static void
-pclose_obj (GJSON * json, int iisp, int last) {
+pclose_obj (GJSON *json, int iisp, int last) {
   if (!last)
     pjson (json, "%.*s%.*s},%.*s", nlines, NL, iisp, TAB, nlines, NL);
   else
@@ -392,7 +392,7 @@ pclose_obj (GJSON * json, int iisp, int last) {
 
 /* Close JSON object. */
 void
-fpclose_obj (FILE * fp, int iisp, int last) {
+fpclose_obj (FILE *fp, int iisp, int last) {
   if (!last)
     fpjson (fp, "%.*s%.*s},%.*s", nlines, NL, iisp, TAB, nlines, NL);
   else
@@ -401,21 +401,21 @@ fpclose_obj (FILE * fp, int iisp, int last) {
 
 /* Write to a buffer a JSON open array attribute. */
 static void
-popen_arr_attr (GJSON * json, const char *attr, int sp) {
+popen_arr_attr (GJSON *json, const char *attr, int sp) {
   /* open object attribute */
   pjson (json, "%.*s\"%s\": [%.*s", sp, TAB, attr, nlines, NL);
 }
 
 /* Output a JSON open array attribute. */
 void
-fpopen_arr_attr (FILE * fp, const char *attr, int sp) {
+fpopen_arr_attr (FILE *fp, const char *attr, int sp) {
   /* open object attribute */
   fpjson (fp, "%.*s\"%s\": [%.*s", sp, TAB, attr, nlines, NL);
 }
 
 /* Close the data array. */
 static void
-pclose_arr (GJSON * json, int sp, int last) {
+pclose_arr (GJSON *json, int sp, int last) {
   if (!last)
     pjson (json, "%.*s%.*s],%.*s", nlines, NL, sp, TAB, nlines, NL);
   else
@@ -424,7 +424,7 @@ pclose_arr (GJSON * json, int sp, int last) {
 
 /* Close the data array. */
 void
-fpclose_arr (FILE * fp, int sp, int last) {
+fpclose_arr (FILE *fp, int sp, int last) {
   if (!last)
     fpjson (fp, "%.*s%.*s],%.*s", nlines, NL, sp, TAB, nlines, NL);
   else
@@ -433,7 +433,7 @@ fpclose_arr (FILE * fp, int sp, int last) {
 
 /* Write to a buffer the date and time for the overall object. */
 static void
-poverall_datetime (GJSON * json, int sp) {
+poverall_datetime (GJSON *json, int sp) {
   char now[DATE_TIME];
 
   generate_time ();
@@ -444,7 +444,7 @@ poverall_datetime (GJSON * json, int sp) {
 
 /* Write to a buffer the date and time for the overall object. */
 static void
-poverall_start_end_date (GJSON * json, GHolder * h, int sp) {
+poverall_start_end_date (GJSON *json, GHolder *h, int sp) {
   char *start = NULL, *end = NULL;
 
   if (h->idx == 0 || get_start_end_parsing_dates (&start, &end, "%d/%b/%Y"))
@@ -459,76 +459,76 @@ poverall_start_end_date (GJSON * json, GHolder * h, int sp) {
 
 /* Write to a buffer date and time for the overall object. */
 static void
-poverall_requests (GJSON * json, int sp) {
+poverall_requests (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_REQ, ht_get_processed (), sp, 0);
 }
 
 /* Write to a buffer the number of valid requests under the overall
  * object. */
 static void
-poverall_valid_reqs (GJSON * json, int sp) {
+poverall_valid_reqs (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_VALID, ht_sum_valid (), sp, 0);
 }
 
 /* Write to a buffer the number of invalid requests under the overall
  * object. */
 static void
-poverall_invalid_reqs (GJSON * json, int sp) {
+poverall_invalid_reqs (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_FAILED, ht_get_invalid (), sp, 0);
 }
 
 /* Write to a buffer the total processed time under the overall
  * object. */
 static void
-poverall_processed_time (GJSON * json, int sp) {
+poverall_processed_time (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_GENTIME, ht_get_processing_time (), sp, 0);
 }
 
 /* Write to a buffer the total number of unique visitors under the
  * overall object. */
 static void
-poverall_visitors (GJSON * json, int sp) {
+poverall_visitors (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_VISITORS, ht_get_size_uniqmap (VISITORS), sp, 0);
 }
 
 /* Write to a buffer the total number of unique files under the
  * overall object. */
 static void
-poverall_files (GJSON * json, int sp) {
+poverall_files (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_FILES, ht_get_size_datamap (REQUESTS), sp, 0);
 }
 
 /* Write to a buffer the total number of excluded requests under the
  * overall object. */
 static void
-poverall_excluded (GJSON * json, int sp) {
+poverall_excluded (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_EXCL_HITS, ht_get_excluded_ips (), sp, 0);
 }
 
 /* Write to a buffer the number of referrers under the overall object. */
 static void
-poverall_refs (GJSON * json, int sp) {
+poverall_refs (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_REF, ht_get_size_datamap (REFERRERS), sp, 0);
 }
 
 /* Write to a buffer the number of not found (404s) under the overall
  * object. */
 static void
-poverall_notfound (GJSON * json, int sp) {
+poverall_notfound (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_NOTFOUND, ht_get_size_datamap (NOT_FOUND), sp, 0);
 }
 
 /* Write to a buffer the number of static files (jpg, pdf, etc) under
  * the overall object. */
 static void
-poverall_static_files (GJSON * json, int sp) {
+poverall_static_files (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_STATIC, ht_get_size_datamap (REQUESTS_STATIC), sp, 0);
 }
 
 /* Write to a buffer the size of the log being parsed under the
  * overall object. */
 static void
-poverall_log_size (GJSON * json, int sp) {
+poverall_log_size (GJSON *json, int sp) {
   pjson (json, "%.*s\"%s\": %jd,%.*s", sp, TAB, OVERALL_LOGSIZE,
          (intmax_t) get_log_sizes (), nlines, NL);
 }
@@ -536,12 +536,12 @@ poverall_log_size (GJSON * json, int sp) {
 /* Write to a buffer the total bandwidth consumed under the overall
  * object. */
 static void
-poverall_bandwidth (GJSON * json, int sp) {
+poverall_bandwidth (GJSON *json, int sp) {
   pskeyu64val (json, OVERALL_BANDWIDTH, ht_sum_bw (), sp, 0);
 }
 
 static void
-poverall_log_path (GJSON * json, int idx, int isp) {
+poverall_log_path (GJSON *json, int idx, int isp) {
   pjson (json, "%.*s\"", isp, TAB);
   if (conf.filenames[idx][0] == '-' && conf.filenames[idx][1] == '\0')
     pjson (json, "STDIN");
@@ -553,7 +553,7 @@ poverall_log_path (GJSON * json, int idx, int isp) {
 /* Write to a buffer the path of the log being parsed under the
  * overall object. */
 static void
-poverall_log (GJSON * json, int sp) {
+poverall_log (GJSON *json, int sp) {
   int idx, isp = 0;
 
   /* use tabs to prettify output */
@@ -568,7 +568,7 @@ poverall_log (GJSON * json, int sp) {
 
 /* Write to a buffer hits data. */
 static void
-phits (GJSON * json, GMetrics * nmetrics, int sp) {
+phits (GJSON *json, GMetrics *nmetrics, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -585,7 +585,7 @@ phits (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer visitors data. */
 static void
-pvisitors (GJSON * json, GMetrics * nmetrics, int sp) {
+pvisitors (GJSON *json, GMetrics *nmetrics, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -602,7 +602,7 @@ pvisitors (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer bandwidth data. */
 static void
-pbw (GJSON * json, GMetrics * nmetrics, int sp) {
+pbw (GJSON *json, GMetrics *nmetrics, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -622,7 +622,7 @@ pbw (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer average time served data. */
 static void
-pavgts (GJSON * json, GMetrics * nmetrics, int sp) {
+pavgts (GJSON *json, GMetrics *nmetrics, int sp) {
   if (!conf.serve_usecs)
     return;
   pskeyu64val (json, "avgts", nmetrics->avgts.nts, sp, 0);
@@ -630,7 +630,7 @@ pavgts (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer cumulative time served data. */
 static void
-pcumts (GJSON * json, GMetrics * nmetrics, int sp) {
+pcumts (GJSON *json, GMetrics *nmetrics, int sp) {
   if (!conf.serve_usecs)
     return;
   pskeyu64val (json, "cumts", nmetrics->cumts.nts, sp, 0);
@@ -638,7 +638,7 @@ pcumts (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer maximum time served data. */
 static void
-pmaxts (GJSON * json, GMetrics * nmetrics, int sp) {
+pmaxts (GJSON *json, GMetrics *nmetrics, int sp) {
   if (!conf.serve_usecs)
     return;
   pskeyu64val (json, "maxts", nmetrics->maxts.nts, sp, 0);
@@ -646,7 +646,7 @@ pmaxts (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer request method data. */
 static void
-pmethod (GJSON * json, GMetrics * nmetrics, int sp) {
+pmethod (GJSON *json, GMetrics *nmetrics, int sp) {
   /* request method */
   if (conf.append_method && nmetrics->method) {
     pskeysval (json, "method", nmetrics->method, sp, 0);
@@ -655,7 +655,7 @@ pmethod (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* Write to a buffer protocol method data. */
 static void
-pprotocol (GJSON * json, GMetrics * nmetrics, int sp) {
+pprotocol (GJSON *json, GMetrics *nmetrics, int sp) {
   /* request protocol */
   if (conf.append_protocol && nmetrics->protocol) {
     pskeysval (json, "protocol", nmetrics->protocol, sp, 0);
@@ -663,7 +663,7 @@ pprotocol (GJSON * json, GMetrics * nmetrics, int sp) {
 }
 
 static void
-pmeta_i64_data (GJSON * json, GHolder * h, void (*cb) (GModule, uint64_t *, uint64_t *),
+pmeta_i64_data (GJSON *json, GHolder *h, void (*cb) (GModule, uint64_t *, uint64_t *),
                 const char *key, int show_perc, int sp) {
   int isp = 0;
   uint64_t max = 0, min = 0, total = ht_get_meta_data (h->module, key);
@@ -702,7 +702,7 @@ pmeta_i64_data (GJSON * json, GHolder * h, void (*cb) (GModule, uint64_t *, uint
 }
 
 static void
-pmeta_i32_data (GJSON * json, GHolder * h, void (*cb) (GModule, uint32_t *, uint32_t *),
+pmeta_i32_data (GJSON *json, GHolder *h, void (*cb) (GModule, uint32_t *, uint32_t *),
                 const char *key, int show_perc, int sp) {
   int isp = 0;
   uint32_t max = 0, min = 0, total = ht_get_meta_data (h->module, key);
@@ -742,7 +742,7 @@ pmeta_i32_data (GJSON * json, GHolder * h, void (*cb) (GModule, uint32_t *, uint
 
 /* Write to a buffer the hits meta data object. */
 static void
-pmeta_data_unique (GJSON * json, int ht_size, int sp) {
+pmeta_data_unique (GJSON *json, int ht_size, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -760,7 +760,7 @@ pmeta_data_unique (GJSON * json, int ht_size, int sp) {
 
 /* Write to a buffer the hits meta data object. */
 static void
-pmeta_data_hits (GJSON * json, GHolder * h, int sp) {
+pmeta_data_hits (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -774,7 +774,7 @@ pmeta_data_hits (GJSON * json, GHolder * h, int sp) {
 
 /* Write to a buffer the visitors meta data object. */
 static void
-pmeta_data_visitors (GJSON * json, GHolder * h, int sp) {
+pmeta_data_visitors (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
 
   /* use tabs to prettify output */
@@ -788,7 +788,7 @@ pmeta_data_visitors (GJSON * json, GHolder * h, int sp) {
 
 /* Write to a buffer the bytes meta data object. */
 static void
-pmeta_data_bw (GJSON * json, GHolder * h, int sp) {
+pmeta_data_bw (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
   if (!conf.bandwidth)
     return;
@@ -805,7 +805,7 @@ pmeta_data_bw (GJSON * json, GHolder * h, int sp) {
 /* Write to a buffer the average of the average time served meta data
  * object. */
 static void
-pmeta_data_avgts (GJSON * json, GHolder * h, int sp) {
+pmeta_data_avgts (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
   uint64_t avg = 0, hits = 0, cumts = 0;
 
@@ -832,7 +832,7 @@ pmeta_data_avgts (GJSON * json, GHolder * h, int sp) {
 
 /* Write to a buffer the cumulative time served meta data object. */
 static void
-pmeta_data_cumts (GJSON * json, GHolder * h, int sp) {
+pmeta_data_cumts (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
 
   if (!conf.serve_usecs)
@@ -849,7 +849,7 @@ pmeta_data_cumts (GJSON * json, GHolder * h, int sp) {
 
 /* Write to a buffer the maximum time served meta data object. */
 static void
-pmeta_data_maxts (GJSON * json, GHolder * h, int sp) {
+pmeta_data_maxts (GJSON *json, GHolder *h, int sp) {
   int isp = 0;
   if (!conf.serve_usecs)
     return;
@@ -865,7 +865,7 @@ pmeta_data_maxts (GJSON * json, GHolder * h, int sp) {
 
 /* Entry point to output panel's metadata. */
 static void
-print_meta_data (GJSON * json, GHolder * h, int sp) {
+print_meta_data (GJSON *json, GHolder *h, int sp) {
   int isp = 0, iisp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -886,7 +886,7 @@ print_meta_data (GJSON * json, GHolder * h, int sp) {
 
 /* A wrapper function to output data metrics per panel. */
 static void
-print_json_block (GJSON * json, GMetrics * nmetrics, int sp) {
+print_json_block (GJSON *json, GMetrics *nmetrics, int sp) {
   /* print hits */
   phits (json, nmetrics, sp);
   /* print visitors */
@@ -911,7 +911,7 @@ print_json_block (GJSON * json, GMetrics * nmetrics, int sp) {
 
 /* A wrapper function to output an array of user agents for each host. */
 static void
-process_host_agents (GJSON * json, GHolderItem * item, int iisp) {
+process_host_agents (GJSON *json, GHolderItem *item, int iisp) {
   GAgents *agents = NULL;
   int i, n = 0, iiisp = 0;
 
@@ -943,7 +943,7 @@ process_host_agents (GJSON * json, GHolderItem * item, int iisp) {
 
 /* A wrapper function to output children nodes. */
 static void
-print_json_sub_items (GJSON * json, GHolderItem * item, GPercTotals totals, int size, int iisp) {
+print_json_sub_items (GJSON *json, GHolderItem *item, GPercTotals totals, int size, int iisp) {
   GMetrics *nmetrics;
   GSubItem *iter;
   GSubList *sl = item->sub_list;
@@ -974,7 +974,7 @@ print_json_sub_items (GJSON * json, GHolderItem * item, GPercTotals totals, int
 
 /* A wrapper function to output geolocation fields for the given host. */
 static void
-print_json_host_geo (GJSON * json, GSubList * sl, int iisp) {
+print_json_host_geo (GJSON *json, GSubList *sl, int iisp) {
   GSubItem *iter;
   int i;
   static const char *key[] = {
@@ -996,8 +996,7 @@ print_json_host_geo (GJSON * json, GSubList * sl, int iisp) {
 
 /* Output Geolocation data and the IP's hostname. */
 static void
-print_json_host_items (GJSON * json, GHolderItem * item, GPercTotals totals,
-                       int size, int iisp) {
+print_json_host_items (GJSON *json, GHolderItem *item, GPercTotals totals, int size, int iisp) {
   (void) totals;
   /* print geolocation fields */
   if (size > 0 && item->sub_list != NULL)
@@ -1010,7 +1009,7 @@ print_json_host_items (GJSON * json, GHolderItem * item, GPercTotals totals,
 
 /* Output data and determine if there are children nodes. */
 static void
-print_data_metrics (GJSON * json, GHolder * h, GPercTotals totals, int sp,
+print_data_metrics (GJSON *json, GHolder *h, GPercTotals totals, int sp,
                     const struct GPanel_ *panel) {
   GMetrics *nmetrics;
   int i, isp = 0, iisp = 0, iiisp = 0;
@@ -1041,7 +1040,7 @@ print_data_metrics (GJSON * json, GHolder * h, GPercTotals totals, int sp,
 
 /* Entry point to output data metrics per panel. */
 static void
-print_json_data (GJSON * json, GHolder * h, GPercTotals totals, const struct GPanel_ *panel) {
+print_json_data (GJSON *json, GHolder *h, GPercTotals totals, const struct GPanel_ *panel) {
   int sp = 0;
   /* use tabs to prettify output */
   if (conf.json_pretty_print)
@@ -1072,7 +1071,7 @@ num_panels (void) {
 
 /* Write to a buffer overall data. */
 static void
-print_json_summary (GJSON * json, GHolder * holder) {
+print_json_summary (GJSON *json, GHolder *holder) {
   int sp = 0, isp = 0;
 
   /* use tabs to prettify output */
@@ -1115,7 +1114,7 @@ print_json_summary (GJSON * json, GHolder * holder) {
 
 /* Iterate over all panels and generate json output. */
 static GJSON *
-init_json_output (GHolder * holder) {
+init_json_output (GHolder *holder) {
   GJSON *json = NULL;
   GModule module;
   GPercTotals totals;
@@ -1148,7 +1147,7 @@ init_json_output (GHolder * holder) {
  *
  * On success, the newly allocated buffer is returned . */
 char *
-get_json (GHolder * holder, int escape_html) {
+get_json (GHolder *holder, int escape_html) {
   GJSON *json = NULL;
   char *buf = NULL;
 
@@ -1166,7 +1165,7 @@ get_json (GHolder * holder, int escape_html) {
 
 /* Entry point to generate a json report writing it to the fp */
 void
-output_json (GHolder * holder, const char *filename) {
+output_json (GHolder *holder, const char *filename) {
   GJSON *json = NULL;
   FILE *fp;
 
