@@ -30,9 +30,14 @@
 #ifndef LABELS_H_INCLUDED
 #define LABELS_H_INCLUDED
 
+#ifdef ENABLE_NLS
 #include <libintl.h>
 
 #define _(String) dgettext (PACKAGE , String)
+#else
+#define _(String) (String)
+#endif
+
 #define gettext_noop(String) String
 #define N_(String) gettext_noop (String)
 
@@ -175,11 +180,11 @@
   N_("Browsers")
 
 #define REFERRERS_HEAD                 \
-  N_("Referer URLs")
+  N_("Referrer URLs")
 #define REFERRERS_DESC                 \
-  N_("Top Requested Referers sorted by hits [, avgts, cumts, maxts]")
+  N_("Top Requested Referrers sorted by hits [, avgts, cumts, maxts]")
 #define REFERRERS_LABEL                \
-  N_("Referers")
+  N_("Referrers")
 
 #define REFERRING_SITES_HEAD           \
   N_("Referring Sites")
