@@ -79,6 +79,147 @@ set_db_path (const char *fn) {
   return path;
 }
 
+/* Given a database filename, restore a string key, uint32_t value back to the
+ * storage */
+static void
+restore_global_si08 (khash_t (si08) *hash, const char *fn) {
+  tpl_node *tn;
+  char *key = NULL;
+  char fmt[] = "A(sv)";
+  uint16_t val;
+
+  tn = tpl_map (fmt, &key, &val);
+  tpl_load (tn, TPL_FILE, fn);
+  while (tpl_unpack (tn, 1) > 0) {
+    ins_si08 (hash, key, val);
+    free (key);
+  }
+  tpl_free (tn);
+}
+
+/* Given a hash and a filename, persist to disk a string key, uint32_t value */
+static void
+persist_global_si08 (khash_t (si08) *hash, const char *fn) {
+  tpl_node *tn;
+  khint_t k;
+  const char *key = NULL;
+  char fmt[] = "A(sv)";
+  uint16_t val;
+
+  if (!hash || kh_size (hash) == 0)
+    return;
+
+  tn = tpl_map (fmt, &key, &val);
+  for (k = 0; k < kh_end (hash); ++k) {
+    if (!kh_exist (hash, k) || (!(key = kh_key (hash, k))))
+      continue;
+    val = kh_value (hash, k);
+    tpl_pack (tn, 1);
+  }
+
+  tpl_dump (tn, TPL_FILE, fn);
+  tpl_free (tn);
+}
+
+/* Given a database filename, restore a string key, uint32_t value back to the
+ * storage */
+static void
+restore_global_si32 (khash_t (si32) *hash, const char *fn) {
+  tpl_node *tn;
+  char *key = NULL;
+  char fmt[] = "A(su)";
+  uint32_t val;
+
+  tn = tpl_map (fmt, &key, &val);
+  tpl_load (tn, TPL_FILE, fn);
+  while (tpl_unpack (tn, 1) > 0) {
+    ins_si32 (hash, key, val);
+    free (key);
+  }
+  tpl_free (tn);
+}
+
+/* Given a hash and a filename, persist to disk a string key, uint32_t value */
+static void
+persist_global_si32 (khash_t (si32) *hash, const char *fn) {
+  tpl_node *tn;
+  khint_t k;
+  const char *key = NULL;
+  char fmt[] = "A(su)";
+  uint32_t val;
+
+  if (!hash || kh_size (hash) == 0)
+    return;
+
+  tn = tpl_map (fmt, &key, &val);
+  for (k = 0; k < kh_end (hash); ++k) {
+    if (!kh_exist (hash, k) || (!(key = kh_key (hash, k))))
+      continue;
+    val = kh_value (hash, k);
+    tpl_pack (tn, 1);
+  }
+
+  tpl_dump (tn, TPL_FILE, fn);
+  tpl_free (tn);
+}
+
+/* Given a database filename, restore a uint64_t key, GLastParse value back to
+ * the storage */
+static void
+restore_global_iglp (khash_t (iglp) *hash, const char *fn) {
+  tpl_node *tn;
+  uint64_t key;
+  GLastParse val = { 0 };
+  char fmt[] = "A(US(uIUvc#))";
+
+  tn = tpl_map (fmt, &key, &val, READ_BYTES);
+  tpl_load (tn, TPL_FILE, fn);
+  while (tpl_unpack (tn, 1) > 0) {
+    ins_iglp (hash, key, val);
+  }
+  tpl_free (tn);
+}
+
+/* Given a hash and a filename, persist to disk a uint64_t key, uint32_t value */
+static void
+persist_global_iglp (khash_t (iglp) *hash, const char *fn) {
+  tpl_node *tn;
+  khint_t k;
+  uint64_t key;
+  GLastParse val = { 0 };
+  char fmt[] = "A(US(uIUvc#))";
+
+  if (!hash || kh_size (hash) == 0)
+    return;
+
+  tn = tpl_map (fmt, &key, &val, READ_BYTES);
+  for (k = 0; k < kh_end (hash); ++k) {
+    if (!kh_exist (hash, k))
+      continue;
+    key = kh_key (hash, k);
+    val = kh_value (hash, k);
+    tpl_pack (tn, 1);
+  }
+
+  tpl_dump (tn, TPL_FILE, fn);
+  tpl_free (tn);
+}
+
+/* Given a filename, ensure we have a valid return path
+ *
+ * On error, NULL is returned.
+ * On success, the valid path is returned */
+static char *
+check_restore_path (const char *fn) {
+  char *path = set_db_path (fn);
+  if (access (path, F_OK) != -1)
+    return path;
+
+  LOG_DEBUG (("DB file %s doesn't exist. %s\n", path, strerror (errno)));
+  free (path);
+  return NULL;
+}
+
 static char *
 build_filename (const char *type, const char *modstr, const char *mtrstr) {
   char *fn = xmalloc (snprintf (NULL, 0, "%s_%s_%s.db", type, modstr, mtrstr) + 1);
@@ -112,133 +253,7 @@ get_filename (GModule module, GKHashMetric mtrc) {
 
 /* Dump to disk the database file and frees its memory */
 static void
-close_tpl (tpl_node * tn, const char *fn) {
-  tpl_dump (tn, TPL_FILE, fn);
-  tpl_free (tn);
-}
-
-/* Given a database filename, restore a string key, uint32_t value back to the
- * storage */
-static void
-restore_global_si08 (khash_t (si08) * hash, const char *fn) {
-  tpl_node *tn;
-  char *key = NULL;
-  char fmt[] = "A(sv)";
-  uint16_t val;
-
-  tn = tpl_map (fmt, &key, &val);
-  tpl_load (tn, TPL_FILE, fn);
-  while (tpl_unpack (tn, 1) > 0) {
-    ins_si08 (hash, key, val);
-    free (key);
-  }
-  tpl_free (tn);
-}
-
-/* Given a hash and a filename, persist to disk a string key, uint32_t value */
-static void
-persist_global_si08 (khash_t (si08) * hash, const char *fn) {
-  tpl_node *tn;
-  khint_t k;
-  const char *key = NULL;
-  char fmt[] = "A(sv)";
-  uint16_t val;
-
-  if (!hash || kh_size (hash) == 0)
-    return;
-
-  tn = tpl_map (fmt, &key, &val);
-  for (k = 0; k < kh_end (hash); ++k) {
-    if (!kh_exist (hash, k) || (!(key = kh_key (hash, k))))
-      continue;
-    val = kh_value (hash, k);
-    tpl_pack (tn, 1);
-  }
-
-  tpl_dump (tn, TPL_FILE, fn);
-  tpl_free (tn);
-}
-
-/* Given a database filename, restore a string key, uint32_t value back to the
- * storage */
-static void
-restore_global_si32 (khash_t (si32) * hash, const char *fn) {
-  tpl_node *tn;
-  char *key = NULL;
-  char fmt[] = "A(su)";
-  uint32_t val;
-
-  tn = tpl_map (fmt, &key, &val);
-  tpl_load (tn, TPL_FILE, fn);
-  while (tpl_unpack (tn, 1) > 0) {
-    ins_si32 (hash, key, val);
-    free (key);
-  }
-  tpl_free (tn);
-}
-
-/* Given a hash and a filename, persist to disk a string key, uint32_t value */
-static void
-persist_global_si32 (khash_t (si32) * hash, const char *fn) {
-  tpl_node *tn;
-  khint_t k;
-  const char *key = NULL;
-  char fmt[] = "A(su)";
-  uint32_t val;
-
-  if (!hash || kh_size (hash) == 0)
-    return;
-
-  tn = tpl_map (fmt, &key, &val);
-  for (k = 0; k < kh_end (hash); ++k) {
-    if (!kh_exist (hash, k) || (!(key = kh_key (hash, k))))
-      continue;
-    val = kh_value (hash, k);
-    tpl_pack (tn, 1);
-  }
-
-  tpl_dump (tn, TPL_FILE, fn);
-  tpl_free (tn);
-}
-
-/* Given a database filename, restore a uint64_t key, GLastParse value back to
- * the storage */
-static void
-restore_global_iglp (khash_t (iglp) * hash, const char *fn) {
-  tpl_node *tn;
-  uint64_t key;
-  GLastParse val = { 0 };
-  char fmt[] = "A(US(uIUvc#))";
-
-  tn = tpl_map (fmt, &key, &val, READ_BYTES);
-  tpl_load (tn, TPL_FILE, fn);
-  while (tpl_unpack (tn, 1) > 0) {
-    ins_iglp (hash, key, val);
-  }
-  tpl_free (tn);
-}
-
-/* Given a hash and a filename, persist to disk a uint64_t key, uint32_t value */
-static void
-persist_global_iglp (khash_t (iglp) * hash, const char *fn) {
-  tpl_node *tn;
-  khint_t k;
-  uint64_t key;
-  GLastParse val = { 0 };
-  char fmt[] = "A(US(uIUvc#))";
-
-  if (!hash || kh_size (hash) == 0)
-    return;
-
-  tn = tpl_map (fmt, &key, &val, READ_BYTES);
-  for (k = 0; k < kh_end (hash); ++k) {
-    if (!kh_exist (hash, k))
-      continue;
-    key = kh_key (hash, k);
-    val = kh_value (hash, k);
-    tpl_pack (tn, 1);
-  }
-
+close_tpl (tpl_node *tn, const char *fn) {
   tpl_dump (tn, TPL_FILE, fn);
   tpl_free (tn);
 }
@@ -874,21 +889,6 @@ persist_igsl (GSMetric metric, const char *path, int module) {
   return 0;
 }
 
-/* Given a filename, ensure we have a valid return path
- *
- * On error, NULL is returned.
- * On success, the valid path is returned */
-static char *
-check_restore_path (const char *fn) {
-  char *path = set_db_path (fn);
-  if (access (path, F_OK) != -1)
-    return path;
-
-  LOG_DEBUG (("DB file %s doesn't exist. %s\n", path, strerror (errno)));
-  free (path);
-  return NULL;
-}
-
 /* Entry function to restore hash data by type */
 static void
 restore_by_type (GKHashMetric mtrc, const char *fn, int module) {
@@ -1009,6 +1009,50 @@ migrate_metric (GModule module, GKHashMetric mtrc) {
   return ret;
 }
 
+static void
+persist_by_type (GKHashMetric mtrc, const char *fn, int module) {
+  char *path = NULL;
+  path = set_db_path (fn);
+
+  switch (mtrc.type) {
+  case MTRC_TYPE_SI32:
+    persist_si32 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_IS32:
+    persist_is32 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_II32:
+    persist_ii32 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_II08:
+    persist_ii08 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_U648:
+    persist_u648 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_IU64:
+    persist_iu64 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_SU64:
+    persist_su64 (mtrc.metric.storem, path, module);
+    break;
+  case MTRC_TYPE_IGSL:
+    persist_igsl (mtrc.metric.storem, path, module);
+    break;
+  default:
+    break;
+  }
+  free (path);
+}
+
+static void
+persist_metric_type (GModule module, GKHashMetric mtrc) {
+  char *fn = NULL;
+  fn = get_filename (module, mtrc);
+  persist_by_type (mtrc, fn, module);
+  free (fn);
+}
+
 /* Given all the dates that we have processed, persist to disk a copy of them. */
 static void
 persist_dates (void) {
@@ -1098,78 +1142,6 @@ restore_global (void) {
   }
 }
 
-/* Entry function to restore hashes */
-void
-restore_data (void) {
-  GModule module;
-  int i, n = 0, migrated = 0;
-  size_t idx = 0;
-
-  restore_global ();
-
-  n = global_metrics_len;
-  for (i = 0; i < n; ++i) {
-    migrated += migrate_metric (-1, global_metrics[i]);
-    restore_by_type (global_metrics[i], global_metrics[i].filename, -1);
-  }
-
-  n = module_metrics_len;
-  FOREACH_MODULE (idx, module_list) {
-    module = module_list[idx];
-    for (i = 0; i < n; ++i) {
-      migrated += migrate_metric (module, module_metrics[i]);
-      restore_metric_type (module, module_metrics[i]);
-    }
-  }
-
-  if (migrated && !conf.persist)
-    conf.persist = 1;
-}
-
-static void
-persist_by_type (GKHashMetric mtrc, const char *fn, int module) {
-  char *path = NULL;
-  path = set_db_path (fn);
-
-  switch (mtrc.type) {
-  case MTRC_TYPE_SI32:
-    persist_si32 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_IS32:
-    persist_is32 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_II32:
-    persist_ii32 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_II08:
-    persist_ii08 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_U648:
-    persist_u648 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_IU64:
-    persist_iu64 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_SU64:
-    persist_su64 (mtrc.metric.storem, path, module);
-    break;
-  case MTRC_TYPE_IGSL:
-    persist_igsl (mtrc.metric.storem, path, module);
-    break;
-  default:
-    break;
-  }
-  free (path);
-}
-
-static void
-persist_metric_type (GModule module, GKHashMetric mtrc) {
-  char *fn = NULL;
-  fn = get_filename (module, mtrc);
-  persist_by_type (mtrc, fn, module);
-  free (fn);
-}
-
 static void
 persist_global (void) {
   GKDB *db = get_db_instance (DB_INSTANCE);
@@ -1210,7 +1182,6 @@ persist_data (void) {
   GModule module;
   int i, n = 0;
   size_t idx = 0;
-
   persist_global ();
 
   n = global_metrics_len;
@@ -1226,6 +1197,35 @@ persist_data (void) {
   }
 }
 
+/* Entry function to restore hashes */
+void
+restore_data (void) {
+  int migrated = 0;
+  GModule module;
+  int i, n = 0;
+  size_t idx = 0;
+
+  restore_global ();
+
+  n = global_metrics_len;
+  for (i = 0; i < n; ++i) {
+    migrated += migrate_metric (-1, global_metrics[i]);
+    restore_by_type (global_metrics[i], global_metrics[i].filename, -1);
+  }
+
+  n = module_metrics_len;
+  FOREACH_MODULE (idx, module_list) {
+    module = module_list[idx];
+    for (i = 0; i < n; ++i) {
+      migrated += migrate_metric (module, module_metrics[i]);
+      restore_metric_type (module, module_metrics[i]);
+    }
+  }
+
+  if (migrated && !conf.persist)
+    conf.persist = 1;
+}
+
 void
 free_persisted_data (void) {
   free (persisted_dates);
